@@ -440,13 +440,13 @@ DImulti_vcovModels <- function(model, MVflag, funcCorr, timeCorr, formulaStart,
   dataMV <- dataMV[order(dataMV[[unitIDs]], dataMV[[Yfunc]]), ]
   dataT <- dataT[order(dataT[[unitIDs]]), ]
 
-  formulaStartT <- paste0("value ~ 0 + ", timeCol, ":((")
+  formulaStartT <- paste0(Yvalue, "~ 0 + ", timeCol, ":((")
   #remove any mention of func
   formulaEndT <- gsub(paste0(Yfunc, "\\s*[:|\\*]"), "", formulaEnd)
   formulaEndT <- gsub(paste0("[:|\\*]\\s*", Yfunc), "", formulaEndT)
   formulaEndT <- gsub(paste0("\\+\\s*", Yfunc), "", formulaEndT)
 
-  formulaStartMV <- paste("value ~ 0 +", Yfunc, ":((")
+  formulaStartMV <- paste(Yvalue, "~ 0 +", Yfunc, ":((")
   #remove any mention of timeCol
   formulaEndMV <- gsub(paste0(timeCol, "\\s*[:|\\*]"), "", formulaEnd)
   formulaEndMV <- gsub(paste0("[:|\\*]\\s*", timeCol), "", formulaEndMV)
